@@ -96,6 +96,11 @@ ImageBrowserPanel::~ImageBrowserPanel()
 
 void ImageBrowserPanel::init()
 {
+#ifdef Q_WS_MAEMO_5
+    ui->layoutFriends->setMargin(0);
+    ui->layoutAlbums->setMargin(0);
+#endif
+
     // Create album list
     listAlbums = new AlbumListWidget(sm);
     ui->layoutAlbums->addWidget(listAlbums);
