@@ -40,6 +40,8 @@ NewsBrowserPanel::~NewsBrowserPanel()
 void NewsBrowserPanel::createLayouts()
 {
     mMainLayout = new QVBoxLayout;
+    mMainLayout->setContentsMargins(2,4,2,4);
+    mMainLayout->setSpacing(0);
     setLayout(mMainLayout);
 
     mTopLayout = new QHBoxLayout;
@@ -108,6 +110,11 @@ void NewsBrowserPanel::initializeModel()
             this, SLOT(setNewsCount(int)));
 }
 
+void NewsBrowserPanel::showFriend(Friend fr)
+{
+    mModel->showFriend(fr);
+}
+
 void NewsBrowserPanel::reloadFeeds(bool update)
 {
     mReloadButton->setIcon(buttonIconStop);
