@@ -108,6 +108,22 @@ void ProfileBrowserPanel::init()
     buttonSendMsg->setEnabled(FALSE);
     ui->layoutProfileTop->addWidget(buttonSendMsg, 1);
 
+    // friend feeds button
+#ifdef DEBUG
+#ifndef Q_WS_MAEMO_5
+    buttonFeeds = new BTN_TYPE(tr("News"));
+    buttonFeeds->setFlat(true);
+#else
+    buttonFeeds = new BTN_TYPE(this);
+    buttonFeeds->setFixedHeight(ICON_SIZE);
+#endif
+    buttonFeeds->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
+    buttonFeeds->setIcon(QIcon(":/res/general_rss.png"));
+    //buttonFeeds->setEnabled(FALSE);
+    ui->layoutProfileTop->addWidget(buttonFeeds, 1);
+    connect(buttonFeeds, SIGNAL(clicked()), SLOT(btnFriendFeeds()));
+#endif
+
     ui->layoutProfileTop->addWidget(buttonRefreshProfile = new QToolButton(this), Qt::AlignRight);
     buttonRefreshProfile->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
     buttonRefreshProfile->setIcon(QIcon::fromTheme("general_refresh", QIcon(":/res/general_refresh.png")));
@@ -132,8 +148,8 @@ void ProfileBrowserPanel::init()
     }
 
     connect(buttonBack, SIGNAL(clicked()), this, SLOT(hideProfile()));
-    connect(buttonAlbums, SIGNAL(clicked()), this, SLOT(showFriendAlbums()));
-    connect(buttonMessages, SIGNAL(clicked()), this, SLOT(showFriendMessages()));
+    connect(buttonAlbums, SIGNAL(clicked()), this, SLOT(btnFriendAlbums()));
+    connect(buttonMessages, SIGNAL(clicked()), this, SLOT(btnFriendMessages()));
     connect(buttonSendMsg, SIGNAL(clicked()), this, SLOT(sendMessageToFriend()));
     connect(buttonRefreshFriends, SIGNAL(clicked()), this,
             SLOT(refreshFriends()));
@@ -338,16 +354,21 @@ void ProfileBrowserPanel::showFriendInfo(Friend fd)
     ownrSelected(fd);
 }
 
-void ProfileBrowserPanel::showFriendAlbums()
+void ProfileBrowserPanel::btnFriendAlbums()
 {
     emit showFriendAlbums(this->friendsPanel->getSelectedFriend());
 }
 
-void ProfileBrowserPanel::showFriendMessages()
+void ProfileBrowserPanel::btnFriendMessages()
 {
     emit showFriendMessages(this->friendsPanel->getSelectedFriend());
 }
 
+void ProfileBrowserPanel::btnFriendFeeds()
+{
+    emit showFriendFeeds(this->friendsPanel->getSelectedFriend());
+}
+
 void ProfileBrowserPanel::sendMessageToFriend()
 {
     Friend fd = this->friendsPanel->getSelectedFriend();
