@@ -146,6 +146,13 @@ signals:
      */
     void showFriendMessages(Friend fd);
 
+    /*!
+      This signal is emitted when user click feeds button.
+
+      \param fd Profile of current friend
+      */
+    void showFriendFeeds(Friend fd);
+
 public slots:
 
 private:    
@@ -163,6 +170,7 @@ private:
 #endif
     BTN_TYPE *buttonAlbums;
     BTN_TYPE *buttonSendMsg;
+    BTN_TYPE *buttonFeeds; /**< Shows friend news */
     QToolButton *buttonBack;
     BTN_TYPE *buttonMessages;
     QFont usedFont;
@@ -187,9 +195,10 @@ private slots:
 
     void hideProfile();
 
-    void showFriendAlbums();
-    void showFriendMessages();
+    void btnFriendAlbums();
+    void btnFriendMessages();
     void sendMessageToFriend();
+    void btnFriendFeeds();
     void orientationChanged();
 
     void updateListFriends(FriendList list, bool isLastUpdate);
