@@ -15,6 +15,7 @@ namespace Ui {
     class QFriendListWidget;
 }
 
+class FilterModel;
 class QToolBar;
 class QFriendListWidget : public QWidget
 {
@@ -55,6 +56,9 @@ private:
     // used model to store list of friends
     QFriendListModel *model;
 
+    // Filter model
+    FilterModel* filterModel;
+
     // the index of selected item
     QModelIndex selectedItem;
 
