@@ -43,6 +43,8 @@ void MessageBrowser::init()
     QHBoxLayout *hLayout = new QHBoxLayout;
     hLayout->addWidget(serviceIcon = new QLabel(this));
     hLayout->addWidget(titleLabel = new QLabel(this));
+    titleLabel->setWordWrap(true);
+    titleLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
     ui->gridLayout->addLayout(hLayout, 0, 0, 1, 2, Qt::AlignCenter);
     ui->gridLayout->addWidget(descLabel = new QLabel(this), 1, 0, 1, 2);
     ui->gridLayout->addWidget(textLabel = new QTextEdit(this), 2, 0, 1, 2);
