@@ -25,11 +25,6 @@ QMessageListWidget::QMessageListWidget(QFont uf, ServiceMgr *sm, QWidget *parent
     buttonEditOwnr->setFlat(TRUE);
     editOwnr->setHintText(tr("Type a title..."));
 
-    connect(editOwnr, SIGNAL(textChanged(QString)),
-            this, SLOT(editOwnr_textChanged(QString)));
-    connect(buttonEditOwnr, SIGNAL(clicked()),
-            this, SLOT(buttonResetOwnr_clicked()));
-
     // set up list view
     ui->treeView->setFont(uf);
     ui->treeView->setItemDelegate(new QMessageDelegate(this->sm, ui->treeView));
@@ -44,6 +39,7 @@ QMessageListWidget::QMessageListWidget(QFont uf, ServiceMgr *sm, QWidget *parent
 
     // prepare model
     filterModel = new FilterModel(sm, this);
+    filterModel->setSortRole(QMessageListModel::SortRole);
     model = new QMessageListModel(this);
     connect(this->sm, SIGNAL(updateMessageList(MessageList,bool)), model, SLOT(updateList(MessageList)));
     connect(this->sm, SIGNAL(messageReaded(QString,QString)), model, SLOT(readMessage(QString, QString)));
@@ -89,6 +85,12 @@ QMessageListWidget::QMessageListWidget(QFont uf, ServiceMgr *sm, QWidget *parent
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     orientationChanged();
 #endif
+
+    // Connect filter field and button
+    connect(editOwnr, SIGNAL(textChanged(QString)),
+            filterModel, SLOT(setFilterString(QString)));
+    connect(buttonEditOwnr, SIGNAL(clicked()),
+            editOwnr, SLOT(clear()));
 }
 
 QMessageListWidget::~QMessageListWidget()
@@ -118,16 +120,6 @@ void QMessageListWidget::itemSelected(QModelIndex in)
     emit ownerSelected(selectedMessage);
 }
 
-void QMessageListWidget::editOwnr_textChanged(QString str)
-{
-    this->model->setNameFilter(str);
-}
-
-void QMessageListWidget::buttonResetOwnr_clicked()
-{
-    editOwnr->clear();
-}
-
 Message QMessageListWidget::getSelectedMessage() const
 {
     // if message was selected
