@@ -42,12 +42,6 @@ public slots:
     // occurs when user selects message on list
     void itemSelected(QModelIndex index);
 
-    // seach field was updated
-    void editOwnr_textChanged(QString str);
-
-    // reset search field
-    void buttonResetOwnr_clicked();
-
     void updateMessages(MessageList list, bool isLastUpdate);
 
 private:
